@@ -746,6 +746,7 @@ types: list[str] = [
     "AWS::Lightsail::Database",
     "AWS::Lightsail::Disk",
     "AWS::Lightsail::Instance",
+    "AWS::Lightsail::InstanceSnapshot",
     "AWS::Lightsail::LoadBalancer",
     "AWS::Lightsail::LoadBalancerTlsCertificate",
     "AWS::Lightsail::StaticIp",
@@ -842,6 +843,7 @@ types: list[str] = [
     "AWS::NetworkFirewall::LoggingConfiguration",
     "AWS::NetworkFirewall::RuleGroup",
     "AWS::NetworkFirewall::TLSInspectionConfiguration",
+    "AWS::NetworkFirewall::VpcEndpointAssociation",
     "AWS::NetworkManager::ConnectAttachment",
     "AWS::NetworkManager::ConnectPeer",
     "AWS::NetworkManager::CoreNetwork",
@@ -1252,7 +1254,9 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
+    "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
+    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -1263,14 +1267,18 @@ cached: list[str] = [
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
+    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
+    "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
+    "aws-apigatewayv2-domainname.json",
     "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
     "aws-apigatewayv2-route.json",
     "aws-apigatewayv2-routeresponse.json",
+    "aws-apigatewayv2-routingrule.json",
     "aws-apigatewayv2-stage.json",
     "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
@@ -1506,13 +1514,10 @@ cached: list[str] = [
     "aws-controltower-enabledbaseline.json",
     "aws-controltower-enabledcontrol.json",
     "aws-controltower-landingzone.json",
-    "aws-customerprofiles-calculatedattributedefinition.json",
     "aws-customerprofiles-domain.json",
     "aws-customerprofiles-eventstream.json",
     "aws-customerprofiles-eventtrigger.json",
     "aws-customerprofiles-integration.json",
-    "aws-customerprofiles-objecttype.json",
-    "aws-customerprofiles-segmentdefinition.json",
     "aws-databrew-dataset.json",
     "aws-databrew-job.json",
     "aws-databrew-project.json",
@@ -1681,7 +1686,6 @@ cached: list[str] = [
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
     "aws-ecs-service.json",
-    "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
     "aws-efs-filesystem.json",
@@ -1939,7 +1943,6 @@ cached: list[str] = [
     "aws-lambda-alias.json",
     "aws-lambda-codesigningconfig.json",
     "aws-lambda-eventinvokeconfig.json",
-    "aws-lambda-eventsourcemapping.json",
     "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
@@ -1960,6 +1963,7 @@ cached: list[str] = [
     "aws-lightsail-database.json",
     "aws-lightsail-disk.json",
     "aws-lightsail-instance.json",
+    "aws-lightsail-instancesnapshot.json",
     "aws-lightsail-loadbalancer.json",
     "aws-lightsail-loadbalancertlscertificate.json",
     "aws-lightsail-staticip.json",
@@ -2054,6 +2058,7 @@ cached: list[str] = [
     "aws-networkfirewall-loggingconfiguration.json",
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
+    "aws-networkfirewall-vpcendpointassociation.json",
     "aws-networkmanager-connectattachment.json",
     "aws-networkmanager-connectpeer.json",
     "aws-networkmanager-corenetwork.json",
@@ -2351,7 +2356,6 @@ cached: list[str] = [
     "aws-stepfunctions-statemachine.json",
     "aws-stepfunctions-statemachinealias.json",
     "aws-stepfunctions-statemachineversion.json",
-    "aws-synthetics-canary.json",
     "aws-synthetics-group.json",
     "aws-systemsmanagersap-application.json",
     "aws-transfer-agreement.json",
