@@ -540,6 +540,7 @@ types: list[str] = [
     "AWS::NetworkFirewall::LoggingConfiguration",
     "AWS::NetworkFirewall::RuleGroup",
     "AWS::NetworkFirewall::TLSInspectionConfiguration",
+    "AWS::NetworkFirewall::VpcEndpointAssociation",
     "AWS::NetworkManager::CustomerGatewayAssociation",
     "AWS::NetworkManager::Device",
     "AWS::NetworkManager::GlobalNetwork",
@@ -569,6 +570,8 @@ types: list[str] = [
     "AWS::Organizations::Policy",
     "AWS::Organizations::ResourcePolicy",
     "AWS::PCS::Cluster",
+    "AWS::PCS::ComputeNodeGroup",
+    "AWS::PCS::Queue",
     "AWS::QuickSight::Analysis",
     "AWS::QuickSight::CustomPermissions",
     "AWS::QuickSight::Dashboard",
@@ -784,7 +787,9 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
+    "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
+    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -795,13 +800,17 @@ cached: list[str] = [
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
+    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
+    "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
+    "aws-apigatewayv2-domainname.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
     "aws-apigatewayv2-route.json",
     "aws-apigatewayv2-routeresponse.json",
+    "aws-apigatewayv2-routingrule.json",
     "aws-apigatewayv2-stage.json",
     "aws-apigatewayv2-vpclink.json",
     "aws-appconfig-application.json",
@@ -876,7 +885,6 @@ cached: list[str] = [
     "aws-cloudformation-waitcondition.json",
     "aws-cloudformation-waitconditionhandle.json",
     "aws-cloudtrail-dashboard.json",
-    "aws-cloudtrail-eventdatastore.json",
     "aws-cloudtrail-resourcepolicy.json",
     "aws-cloudtrail-trail.json",
     "aws-cloudwatch-alarm.json",
@@ -956,7 +964,6 @@ cached: list[str] = [
     "aws-ec2-clientvpntargetnetworkassociation.json",
     "aws-ec2-customergateway.json",
     "aws-ec2-dhcpoptions.json",
-    "aws-ec2-ec2fleet.json",
     "aws-ec2-egressonlyinternetgateway.json",
     "aws-ec2-eip.json",
     "aws-ec2-enclavecertificateiamroleassociation.json",
@@ -991,7 +998,6 @@ cached: list[str] = [
     "aws-ec2-securitygroupingress.json",
     "aws-ec2-securitygroupvpcassociation.json",
     "aws-ec2-snapshotblockpublicaccess.json",
-    "aws-ec2-spotfleet.json",
     "aws-ec2-subnet.json",
     "aws-ec2-subnetcidrblock.json",
     "aws-ec2-subnetnetworkaclassociation.json",
@@ -1040,8 +1046,6 @@ cached: list[str] = [
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
-    "aws-ecs-service.json",
-    "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
     "aws-efs-filesystem.json",
@@ -1051,7 +1055,6 @@ cached: list[str] = [
     "aws-eks-cluster.json",
     "aws-eks-identityproviderconfig.json",
     "aws-eks-nodegroup.json",
-    "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
@@ -1191,6 +1194,7 @@ cached: list[str] = [
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-function.json",
     "aws-lambda-permission.json",
+    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-licensemanager-grant.json",
     "aws-licensemanager-license.json",
@@ -1227,6 +1231,7 @@ cached: list[str] = [
     "aws-networkfirewall-loggingconfiguration.json",
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
+    "aws-networkfirewall-vpcendpointassociation.json",
     "aws-networkmanager-customergatewayassociation.json",
     "aws-networkmanager-device.json",
     "aws-networkmanager-globalnetwork.json",
@@ -1256,6 +1261,8 @@ cached: list[str] = [
     "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
     "aws-pcs-cluster.json",
+    "aws-pcs-computenodegroup.json",
+    "aws-pcs-queue.json",
     "aws-quicksight-analysis.json",
     "aws-quicksight-custompermissions.json",
     "aws-quicksight-dashboard.json",
@@ -1324,6 +1331,7 @@ cached: list[str] = [
     "aws-s3outposts-bucket.json",
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
+    "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
     "aws-sagemaker-domain.json",
     "aws-sagemaker-image.json",
@@ -1406,6 +1414,7 @@ cached: list[str] = [
     "aws-stepfunctions-statemachine.json",
     "aws-stepfunctions-statemachinealias.json",
     "aws-stepfunctions-statemachineversion.json",
+    "aws-synthetics-canary.json",
     "aws-synthetics-group.json",
     "aws-transfer-agreement.json",
     "aws-transfer-certificate.json",
